Pyrallel
========

.. begin-intro

Yet another easy-to-use python parallel library for humans.

.. image:: https://img.shields.io/badge/license-MIT-blue.svg
    :target: https://raw.githubusercontent.com/usc-isi-i2/pyrallel/master/LICENSE
    :alt: License

.. image:: https://github.com/usc-isi-i2/pyrallel/workflows/Tests/badge.svg?branch=master
    :target: https://github.com/usc-isi-i2/pyrallel/actions
    :alt: Github actions

.. image:: https://coveralls.io/repos/github/usc-isi-i2/pyrallel/badge.svg?branch=master
    :target: https://coveralls.io/github/usc-isi-i2/pyrallel?branch=master
    :alt: Coveralls

.. image:: https://badge.fury.io/py/pyrallel.lib.svg
    :target: https://badge.fury.io/py/pyrallel.lib
    :alt: pypi

.. image:: https://readthedocs.org/projects/pyrallel/badge/?version=latest
    :target: http://pyrallel.readthedocs.io/en/latest
    :alt: Documents

- ParallelProcessor: Newbie-friendly process-based parallel computing api.
- MapReduce: Ultimately simple map and reduce computing model.
- ShmQueue: Extremely fast shared memory driven general purpose multiprocessing queue.

.. end-intro

Installation
------------
::

    pip install pyrallel.lib


Documentation
-------------

`Read the Doc <http://pyrallel.readthedocs.io>`_
